@@ -1,14 +1,11 @@
 import numpy as np
 
-class Higham(Exception):
-    pass
-
-def cycol(mn, k = None):
+def cycol(mn, k=None):
     """
     cycol   matrix whose columns repeat cyclically.
-        a = cycol(mn, k) (mn is a 2-tuple) is an m-by-n matrix of 
-        the form a = b(1:m,1:n) where b = [c c c...] and c = randn(m, k).  
-        Thus a's columns repeat cyclically, and a has rank at most k.   
+        a = cycol(mn, k) (mn is a 2-tuple) is an m-by-n matrix of
+        the form a = b(1:m,1:n) where b = [c c c...] and c = randn(m, k).
+        Thus a's columns repeat cyclically, and a has rank at most k.
         k need not divide n. k defaults to round(n/4).
         cycol(n, k), where n is a scalar, is the same as cycol((n n), k).
 
@@ -22,17 +19,17 @@ def cycol(mn, k = None):
         n = mn
 
     if k == None:
-        k = max(round(n/4.),1)
+        k = max(round(n / 4.), 1)
     else:
         if k > n:
-            raise Higham("k cannot be greater than the max matrix dimension")
+            raise ValueError("k cannot be greater than the max matrix dimension")
 
     a = np.random.randn(m, k)
 
-    for i in range(1, int(np.ceil(n/k))):
-        a = np.r_['1',a, a[:,0:k]]         # this is the same as np.hstack(a,...)
+    for i in range(1, int(np.ceil(n / k))):
+        a = np.r_['1', a, a[:, 0:k]]        # this is the same as np.hstack(a,...)
 
-    # Truncate matrix down to desired size if we concat'ed too much 
+    # Truncate matrix down to desired size if we concat'ed too much
     a = a[:, 0:n]
 
     return a
