@@ -20,29 +20,28 @@ of Test Matrix package [2]
 Don MacMillen 15 May 2009
 """
 
-from augment import *
-from bandred import *
-from cgs import *
-from cond import *
-from condeig import *
-from cpltaxes import *
-from dual import *
-from ge import *
-from hankel import *
-from house import *
-from mdsmax import *
-from mgs import *
-from pow2 import *
-from ps import *
-from repmat import *
-from rq import *
-from see import *
-from skewpart import *
-from sparsify import *
-from sub import *
-from symmpart import *
-from toeplitz import *
-from treshape import *
-from tridiag import *
-from vand import *
-from vecperm import *
+from rogues.utils.augment import *
+from rogues.utils.bandred import *
+from rogues.utils.cgs import *
+from rogues.utils.cond import *
+from rogues.utils.condeig import *
+from rogues.utils.cpltaxes import *
+from rogues.utils.dual import *
+from rogues.utils.ge import *
+from rogues.utils.hankel import *
+from rogues.utils.house import *
+from rogues.utils.mdsmax import *
+from rogues.utils.mgs import *
+from rogues.utils.pow2 import *
+from rogues.utils.ps import *
+from rogues.utils.repmat import *
+from rogues.utils.rq import *
+from rogues.utils.skewpart import *
+from rogues.utils.sparsify import *
+from rogues.utils.sub import *
+from rogues.utils.symmpart import *
+from rogues.utils.toeplitz import *
+from rogues.utils.treshape import *
+from rogues.utils.tridiag import *
+from rogues.utils.vand import *
+from rogues.utils.vecperm import *
